@@ -62,20 +62,20 @@ def show_severity(data):
         return state
 
 
-def show_service(data):
+def show_by_dimension(data, dim_name):
     if 'dimensions' in data['expression_data']:
         dimensions = data['expression_data']['dimensions']
-        if 'service' in dimensions:
-            return str(data['expression_data']['dimensions']['service'])
+        if dim_name in dimensions:
+            return str(data['expression_data']['dimensions'][dim_name])
     return ""
 
 
+def show_service(data):
+    return show_by_dimension(data, 'service')
+
+
 def show_host(data):
-    if 'dimensions' in data['expression_data']:
-        dimensions = data['expression_data']['dimensions']
-        if 'hostname' in dimensions:
-            return str(data['expression_data']['dimensions']['hostname'])
-    return ""
+    return show_by_dimension(data, 'hostname')
 
 
 class ShowAlarmHistory(tables.LinkAction):
@@ -132,9 +132,10 @@ class GraphMetric(tables.LinkAction):
 
     def get_link_url(self, datum):
         name = datum['expression_data']['metric_name']
+        threshold = datum['expression_data']['threshold']
         self.attrs['target'] = '_blank'
-        return "/static/grafana/index.html#/dashboard/script/detail.js?token=%s&name=%s" % \
-               (self.table.request.user.token.id, name)
+        return "/static/grafana/index.html#/dashboard/script/detail.js?token=%s&name=%s&threshold=%s" % \
+               (self.table.request.user.token.id, name, threshold)
 
     def allowed(self, request, datum=None):
         return 'metric_name' in datum['expression_data']
@@ -167,7 +168,7 @@ class AlarmsTable(tables.DataTable):
                            filters=[show_status, template.defaultfilters.safe])
     target = tables.Column('name', verbose_name=_('Name'),
                            link=constants.URL_PREFIX + 'alarm_detail',
-                           link_classes=('ajax-modal',))
+                           )
     description = tables.Column('description', verbose_name=_('Description'))
     host = tables.Column(transform=show_host, verbose_name=_('Host'))
     service = tables.Column(transform=show_service, verbose_name=_('Service'))
@@ -191,6 +192,7 @@ class AlarmsTable(tables.DataTable):
                        )
         table_actions = (CreateAlarm,
                          AlarmsFilterAction,
+                         DeleteAlarm,
                         )
 
 
