@@ -22,8 +22,8 @@ import horizon
 class Monitoring(horizon.Dashboard):
     name = _("Monitoring")
     slug = "monitoring"
-    panels = ('alarms', 'notifications')
-    default_panel = 'alarms'
+    panels = ('overview', 'alarms', 'notifications')
+    default_panel = 'overview'
 
 
 horizon.register(Monitoring)
